@@ -778,10 +778,10 @@ double hawki_get_mean_airmass(cpl_frameset *   set)
     - and + -> chip 4
  */
 /*----------------------------------------------------------------------------*/
-int * hawki_detectors_labelise
+cpl_size * hawki_detectors_labelise
 (const cpl_frameset * in)
 {
-    int             *   labels ;
+    cpl_size        *   labels ;
     cpl_bivector    *   offsets ;
     int                 nframes ;
     double          *   poff_x ;
@@ -809,7 +809,7 @@ int * hawki_detectors_labelise
     off_y_mean = cpl_vector_get_mean(cpl_bivector_get_y(offsets));
     
     /* Allocate labels */
-    labels = cpl_malloc(nframes * sizeof(int)) ;
+    labels = cpl_malloc(nframes * sizeof(cpl_size)) ;
     for (i=0 ; i<nframes ; i++) {
         if (poff_x[i] - off_x_mean <= 0 && poff_y[i] - off_y_mean <= 0)
             labels[i] = 1 ;
