@@ -563,7 +563,7 @@ static cpl_table ** hawki_cal_zpoint_reduce
     cur_frame = cpl_frameset_get_position(set, 0) ;
     plist=cpl_propertylist_load(cpl_frame_get_filename(cur_frame), 0) ;
     if ((sval = hawki_pfits_get_filter(plist)) == NULL) return NULL ;
-    else sprintf(hawki_cal_zpoint_outputs.filter, sval) ;
+    else sprintf(hawki_cal_zpoint_outputs.filter, "%s", sval) ;
     if (hawki_cal_zpoint_config.target_ra > 998.0)
     {
         hawki_cal_zpoint_config.target_ra = hawki_pfits_get_targ_alpha(plist);
@@ -684,6 +684,7 @@ static cpl_table ** hawki_cal_zpoint_reduce
 
     /* Check all the detectors have one std star */
     cpl_msg_info(__func__, "Check that all the detectors have one STD star");
+    nframes = cpl_frameset_get_size(set) ;
     if(hawki_check_stdstar_alldetectors(labels, nframes) != 0)
     {
         cpl_msg_error(__func__, "Not all the detectors have STD observations");
@@ -712,7 +713,6 @@ static cpl_table ** hawki_cal_zpoint_reduce
     *star_images = cpl_imagelist_new();
 
     /* Loop on the detectors */
-    nframes = cpl_frameset_get_size(set) ;
     cpl_msg_info(__func__,"Loop on the chips");
     cpl_msg_indent_more() ;
     for(idet = 0; idet < HAWKI_NB_DETECTORS; ++idet)
